summaryrefslogtreecommitdiffstats
path: root/util
diff options
context:
space:
mode:
authorMartin Roth <gaumless@gmail.com>2023-01-04 21:27:06 -0700
committerMartin L Roth <gaumless@gmail.com>2023-01-12 03:13:17 +0000
commit20646cdbe80737e3a931dec70a8279163b2a9d60 (patch)
tree54a14680804d1cb8cbd0d2000dd0b3ec8319945b /util
parentba2cef5b54938cce17871143ea9bbd3fc6868971 (diff)
downloadcoreboot-20646cdbe80737e3a931dec70a8279163b2a9d60.tar.gz
coreboot-20646cdbe80737e3a931dec70a8279163b2a9d60.tar.bz2
coreboot-20646cdbe80737e3a931dec70a8279163b2a9d60.zip
soc/amd: Change Morgana codename to Phoenix
Now that the next generation of APUs is officially announced, we can unmask morgana. The chip formerly known as Morgana is actually Phoenix. Surprise! This patch just changes the name across the entire codebase. Note that the fw.cfg file will stay pointing to the 3rdparty/amd_blobs/morgana/psp directory until the amd_blobs_repo is updated. Signed-off-by: Martin Roth <martin.roth@amd.corp-partner.google.com> Change-Id: Ie9492a30ae9ff9cd7e15e0f2d239c32190ad4956 Reviewed-on: https://review.coreboot.org/c/coreboot/+/71731 Reviewed-by: Fred Reitberger <reitbergerfred@gmail.com> Reviewed-by: Marshall Dawson <marshalldawson3rd@gmail.com> Reviewed-by: Jason Glenesk <jason.glenesk@gmail.com> Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Diffstat (limited to 'util')
-rw-r--r--util/amdfwtool/amdfwtool.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/util/amdfwtool/amdfwtool.c b/util/amdfwtool/amdfwtool.c
index 997a948baeb7..bf1c0b225111 100644
--- a/util/amdfwtool/amdfwtool.c
+++ b/util/amdfwtool/amdfwtool.c
@@ -207,7 +207,7 @@ static void usage(void)
printf(" area\n");
printf("--soc-name <socname> Specify SOC name. Supported names are\n");
printf(" Stoneyridge, Raven, Picasso, Renoir, Cezanne\n");
- printf(" Mendocino, Morgana, Glinda, or Lucienne\n");
+ printf(" Mendocino, Phoenix, Glinda, or Lucienne\n");
printf("\nEmbedded Firmware Structure options used by the PSP:\n");
printf("--spi-speed <HEX_VAL> SPI fast speed to place in EFS Table\n");
printf(" 0x0 66.66Mhz\n");
@@ -654,7 +654,7 @@ enum platform {
PLATFORM_CEZANNE,
PLATFORM_MENDOCINO,
PLATFORM_LUCIENNE,
- PLATFORM_MORGANA,
+ PLATFORM_PHOENIX,
PLATFORM_GLINDA
};
@@ -1937,8 +1937,8 @@ static int set_efs_table(uint8_t soc_id, amd_cb_config *cb_config,
return 1;
}
break;
- /* TODO: Update for morgana and glinda */
- case PLATFORM_MORGANA:
+ /* TODO: Update for phoenix and glinda */
+ case PLATFORM_PHOENIX:
case PLATFORM_GLINDA:
break;
case PLATFORM_UNKNOWN:
@@ -2013,8 +2013,8 @@ static int identify_platform(char *soc_name)
return PLATFORM_RENOIR;
else if (!strcasecmp(soc_name, "Lucienne"))
return PLATFORM_LUCIENNE;
- else if (!strcasecmp(soc_name, "Morgana"))
- return PLATFORM_MORGANA;
+ else if (!strcasecmp(soc_name, "Phoenix"))
+ return PLATFORM_PHOENIX;
else if (!strcasecmp(soc_name, "Glinda"))
return PLATFORM_GLINDA;
else